@@ -1,7 +1,7 @@
 package # hide from PAUSE
     Local::C3;
 
-our @ISA = qw(Local::C1);
+BEGIN { our @ISA = qw(Local::C1) }
 
 use Class::Accessor::Array {
     accessors => {
